
.. _install:

Installation
============

The following details how to install the ``jdaviz`` Python package.

Quick Installation
------------------

Installing the released version can be done using pip::

    pip install jdaviz

or  if you want the latest in-development version, you can install via Github::

   pip install git+https://github.com/spacetelescope/jdaviz --upgrade

Developer Installation
----------------------

To install ``jdaviz`` for development, or from source::

   git clone https://github.com/spacetelescope/jdaviz.git
   cd jdaviz
   pip install -e .

See :ref:`quickstart` to learn how to run ``jdaviz``.
